/* SPDX-License-Identifier: LGPL-2.1-only OR BSD-3-Clause */
/******************************************************************************
 *
 * This file is provided under a dual license.  When you use or
 * distribute this software, you may choose to be licensed under
 * version 2.1 of the GNU Lesser General Public License
 * ("LGPLv2.1 License") or BSD License.
 *
 * LGPLv2.1 License
 *
 * Copyright(C) 2019 MediaTek Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2.1 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html for more
 * details.
 *
 * BSD LICENSE
 *
 * Copyright(C) 2019 MediaTek Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/*-----------------------------------------------------------------------------
 * $Author: dtvbm11 $
 * $Date: 2015/11/10 $
 * $RCSfile: cb_nptv.c,v $
 * $Revision: #1 $
 *---------------------------------------------------------------------------*/

/** @file cb_nptv.c
 *  This file implements callback interface of mpv for resolution change.
 */


//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------

#include "cb_low.h"
#include "nptv_if.h"
#include "video_timing.h"
#include <linux/module.h>

#if 0
typedef void (*NPTV_PFN_SIG_NFY_FCT)(
    void*               pvNfyTag,
    UINT32     		u4SigStatus,
    UINT32              u4SigSrc
);

typedef struct _NPTV_SIG_NFY_INFO_T_
{
    void*                        		pvTag;        /* pull mode only */
    NPTV_PFN_SIG_NFY_FCT   		pfSigNfy; /* pull mode only */

}NPTV_SIG_NFY_INFO_T;
#endif

EXTERN UINT16 wDrvVideoInputWidth(UINT8 bPath);
EXTERN UINT16 wDrvVideoInputHeight(UINT8 bPath);
EXTERN UINT8 bDrvVideoIsSrcInterlace(UINT8 bPath);


//-----------------------------------------------------------------------------
// Static functions
//-----------------------------------------------------------------------------

#ifdef CC_DRIVER_PROGRAM
//-----------------------------------------------------------------------------
/** NPTV callback function.
 *  @param  pvNfyTag
 *  @param  u4SigStatus 
 *  @param  u4SigSrc     
 */
//-----------------------------------------------------------------------------

static void _NPTVCbFct(void* pvNfyTag, UINT32 u4SigStatus, UINT32 u4SigSrc)
{
    UINT32 u4VdpId = (UINT32)pvNfyTag;
    NPTV_CB_T rNPTVCb;

    rNPTVCb.ucVdpId = (UINT8)pvNfyTag;
    rNPTVCb.u4SigStatus = u4SigStatus;
    if(fgIsOversampleTiming())
    {
        rNPTVCb.u2W = wDrvVideoInputWidth(u4VdpId) / 2;
    }
    else
    {
        rNPTVCb.u2W = wDrvVideoInputWidth(u4VdpId);
    }
    rNPTVCb.u2H = wDrvVideoInputHeight(u4VdpId);
    rNPTVCb.ucProgressive = !(unsigned char)bDrvVideoIsSrcInterlace(u4VdpId);
         
    _CB_PutEvent(CB_NPTV_TRIGGER, sizeof(NPTV_CB_T), &rNPTVCb);

}
#endif /* CC_DRIVER_PROGRAM */

//-----------------------------------------------------------------------------
/** To register/enable NPTV callback function.
 *  @param  i4SubId     ID to identify subcomponent, or other parameter.
 *  @retval CBR_OK      Success.
 */
//-----------------------------------------------------------------------------

INT32 _NPTV_RegTrigger(INT32 i4SubId)
{
#ifdef CC_DRIVER_PROGRAM
    int idx;
    NPTV_PFN_SIG_NFY_FCT pfFct;

    pfFct = _NPTVCbFct;

    NPTV_SetSigChgNfyFct(pfFct);
#endif
    return CBR_OK;
}
